import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { NgxDaterangepickerLocaleService } from "../../services/ngx-daterangepicker-locale.service";
import { Dayjs } from "dayjs";
import { SideEnum } from "../../enums/side.enum";
import * as i0 from "@angular/core";
export declare class NgxDaterangepickerBootstrapComponent implements OnInit, OnChanges {
    private el;
    private _ref;
    private _localeService;
    $event: any;
    chosenLabel?: string;
    calendarVariables: {
        left: any;
        right: any;
    };
    timepickerVariables: {
        left: any;
        right: any;
    };
    applyBtn: {
        disabled: boolean;
    };
    chosenRange?: string | null;
    rangesArray: Array<any>;
    isShown: Boolean;
    inline: boolean;
    showCalInRanges: Boolean;
    private tooltiptext;
    private leftCalendar;
    private rightCalendar;
    private nowHoveredDate;
    private pickingDate;
    private _old;
    _minDate?: Dayjs | null;
    _maxDate?: Dayjs | null;
    private _locale;
    private _ranges;
    startDate: Dayjs | undefined | null;
    endDate: Dayjs | undefined | null;
    dateLimit: number | null;
    autoApply: Boolean;
    singleDatePicker: Boolean;
    showDropdowns: Boolean;
    showWeekNumbers: Boolean;
    showISOWeekNumbers: Boolean;
    linkedCalendars: Boolean;
    autoUpdateInput: Boolean;
    alwaysShowCalendars: Boolean;
    maxSpan: Boolean;
    lockStartDate: Boolean;
    timePicker: Boolean;
    timePicker24Hour: Boolean;
    timePickerIncrement: number;
    timePickerSeconds: Boolean;
    showClearButton: Boolean;
    firstMonthDayClass: string | null | undefined;
    lastMonthDayClass: string | null | undefined;
    emptyWeekRowClass: string | null | undefined;
    emptyWeekColumnClass: string | null | undefined;
    firstDayOfNextMonthClass: string | null | undefined;
    lastDayOfPreviousMonthClass: string | null | undefined;
    showCustomRangeLabel?: boolean;
    showCancel: boolean;
    keepCalendarOpeningWithRange: boolean;
    showRangeLabelOnInput: boolean;
    customRangeDirection: boolean;
    drops?: string;
    opens?: string;
    closeOnAutoApply: boolean;
    set minDate(value: Dayjs | string);
    set maxDate(value: Dayjs | string);
    set locale(value: any);
    set ranges(value: any);
    chosenDate: EventEmitter<Object>;
    rangeClicked: EventEmitter<Object>;
    datesUpdated: EventEmitter<Object>;
    startDateChanged: EventEmitter<Object>;
    endDateChanged: EventEmitter<Object>;
    cancelClicked: EventEmitter<Object>;
    clearClicked: EventEmitter<void>;
    pickerContainer?: ElementRef;
    getMinDate(): Dayjs | null | undefined;
    getMaxDate(): Dayjs | null | undefined;
    get locale(): any;
    get ranges(): any;
    constructor(el: ElementRef, _ref: ChangeDetectorRef, _localeService: NgxDaterangepickerLocaleService);
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    renderRanges(): void;
    renderTimePicker(side: SideEnum): void;
    renderCalendar(side: SideEnum): void;
    setStartDate(startDate: any): void;
    setEndDate(endDate: any): void;
    isInvalidDate(date: any): any;
    isCustomDate(date: any): any;
    isTooltipDate(date: any): any;
    updateView(): void;
    updateMonthsInView(): void;
    /**
     *  This is responsible for updating the calendars
     */
    updateCalendars(): void;
    updateElement(): void;
    remove(): void;
    /**
     * this should calculate the label
     */
    calculateChosenLabel(): void;
    clickApply(e?: any): void;
    clickCancel(e: any): void;
    /**
     * called when month is changed
     * @param object get value in event.target.value / left or right
     */
    monthChanged(object: {
        $event: any;
        side: SideEnum;
    }): void;
    /**
     * called when year is changed
     * @param object get value in event.target.value / left or right
     */
    yearChanged(object: {
        $event: any;
        side: SideEnum;
    }): void;
    /**
     * called when time is changed
     * @param object get value in event.target.value / left or right
     */
    timeChanged(object: {
        $event: any;
        side: SideEnum;
    }): void;
    /**
     *  call when month or year changed
     * @param month month number 0 -11
     * @param year year eg: 1995
     * @param side left or right
     */
    monthOrYearChanged(month: number, year: number, side: SideEnum): void;
    /**
     * Click on previous month
     * @param object left or right calendar
     */
    clickPrev(object: {
        $event: MouseEvent;
        side: SideEnum;
    }): void;
    /**
     * Click on next month
     * @param side left or right calendar
     */
    clickNext(object: {
        $event: MouseEvent;
        side: SideEnum;
    }): void;
    /**
     * When hovering a date
     * @param object get value by e.target.value / side left or right / row position of the current date clicked / col position of the current date clicked
     */
    hoverDate(object: {
        $event: any;
        side: SideEnum;
        row: number;
        col: number;
    }): void;
    /**
     * When selecting a date
     * @param object get value by e.target.value / side left or right / row position of the current date clicked / col position of the current date clicked
     */
    clickDate(object: {
        $event: any;
        side: SideEnum;
        row: number;
        col: number;
    }): void;
    /**
     *  Click on the custom range
     * @param object
     */
    clickRange(object: {
        $event: MouseEvent;
        label: string;
    }): void;
    show(e?: any): void;
    hide(e?: any): void;
    clearIncompleteDateSelection(): void;
    /**
     * handle click on all element in the component, useful for outside of click
     * @param e event
     */
    handleInternalClick(e: any): void;
    /**
     * update the services options
     * @param locale
     */
    updateLocale(locale: any): void;
    /**
     *  clear the daterange picker
     */
    clickClear($event: any): void;
    /**
     * Find out if the selected range should be disabled if it doesn't
     * fit into minDate and maxDate limitations.
     */
    disableRange(range: any): any;
    /**
     *
     * @param date the date to add time
     * @param side left or right
     */
    private _getDateWithTime;
    /**
     *  build the services config
     */
    private _buildLocale;
    private _buildCells;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxDaterangepickerBootstrapComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxDaterangepickerBootstrapComponent, "ngx-daterangepicker-bootstrap", never, { "startDate": { "alias": "startDate"; "required": false; }; "endDate": { "alias": "endDate"; "required": false; }; "dateLimit": { "alias": "dateLimit"; "required": false; }; "autoApply": { "alias": "autoApply"; "required": false; }; "singleDatePicker": { "alias": "singleDatePicker"; "required": false; }; "showDropdowns": { "alias": "showDropdowns"; "required": false; }; "showWeekNumbers": { "alias": "showWeekNumbers"; "required": false; }; "showISOWeekNumbers": { "alias": "showISOWeekNumbers"; "required": false; }; "linkedCalendars": { "alias": "linkedCalendars"; "required": false; }; "autoUpdateInput": { "alias": "autoUpdateInput"; "required": false; }; "alwaysShowCalendars": { "alias": "alwaysShowCalendars"; "required": false; }; "maxSpan": { "alias": "maxSpan"; "required": false; }; "lockStartDate": { "alias": "lockStartDate"; "required": false; }; "timePicker": { "alias": "timePicker"; "required": false; }; "timePicker24Hour": { "alias": "timePicker24Hour"; "required": false; }; "timePickerIncrement": { "alias": "timePickerIncrement"; "required": false; }; "timePickerSeconds": { "alias": "timePickerSeconds"; "required": false; }; "showClearButton": { "alias": "showClearButton"; "required": false; }; "firstMonthDayClass": { "alias": "firstMonthDayClass"; "required": false; }; "lastMonthDayClass": { "alias": "lastMonthDayClass"; "required": false; }; "emptyWeekRowClass": { "alias": "emptyWeekRowClass"; "required": false; }; "emptyWeekColumnClass": { "alias": "emptyWeekColumnClass"; "required": false; }; "firstDayOfNextMonthClass": { "alias": "firstDayOfNextMonthClass"; "required": false; }; "lastDayOfPreviousMonthClass": { "alias": "lastDayOfPreviousMonthClass"; "required": false; }; "showCustomRangeLabel": { "alias": "showCustomRangeLabel"; "required": false; }; "showCancel": { "alias": "showCancel"; "required": false; }; "keepCalendarOpeningWithRange": { "alias": "keepCalendarOpeningWithRange"; "required": false; }; "showRangeLabelOnInput": { "alias": "showRangeLabelOnInput"; "required": false; }; "customRangeDirection": { "alias": "customRangeDirection"; "required": false; }; "drops": { "alias": "drops"; "required": false; }; "opens": { "alias": "opens"; "required": false; }; "closeOnAutoApply": { "alias": "closeOnAutoApply"; "required": false; }; "minDate": { "alias": "minDate"; "required": false; }; "maxDate": { "alias": "maxDate"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "ranges": { "alias": "ranges"; "required": false; }; "isInvalidDate": { "alias": "isInvalidDate"; "required": false; }; "isCustomDate": { "alias": "isCustomDate"; "required": false; }; "isTooltipDate": { "alias": "isTooltipDate"; "required": false; }; }, { "chosenDate": "chosenDate"; "rangeClicked": "rangeClicked"; "datesUpdated": "datesUpdated"; "startDateChanged": "startDateChanged"; "endDateChanged": "endDateChanged"; "cancelClicked": "cancelClicked"; "clearClicked": "clearClicked"; }, never, never, true, never>;
}
